@@ -66,7 +66,7 @@ def QuantitativeScoreFile(lllleaf, llllleaf, mav:float, miv:float, ScoreFile, ma
     for row in csv_reader:
         #print(row)
         if len(row) == 3:
-            if isNum(row[2]):
+            if row[2].isdigit():
                 score_dict[row[0]+ '_' + row[1]] = float(row[2])
                 score_dict[row[1]+ '_' + row[0]] = float(row[2])
         else:
